AccountGasMeterPoint class

Inheritance

Constructors

AccountGasMeterPoint({List<AccountAgreement>? agreements, int? consumptionStandard, List<AccountGasMeterPointMeter>? meters, required String mprn})
AccountGasMeterPoint.fromJson(Map<String, dynamic> json)
factory

Properties

agreements List<AccountAgreement>?
getter/setter pairinherited
consumptionStandard int?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
meters List<AccountGasMeterPointMeter>?
getter/setter pairinherited
mprn String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited