AccountMeterPoint<T extends AccountMeterPointMeter> class abstract

Implementers

Constructors

AccountMeterPoint({List<AccountAgreement>? agreements, int? consumptionStandard, List<T>? meters})

Properties

agreements List<AccountAgreement>?
getter/setter pair
consumptionStandard int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
meters List<T>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited