AccountType enum
Values
- anonymised → const AccountType
- business → const AccountType
- businessOccupier → const AccountType
- businessThirdPartyBilled → const AccountType
- businessVacant → const AccountType
- domestic → const AccountType
- domesticThirdPartyBilled → const AccountType
- domesticVacant → const AccountType
- managed → const AccountType
- occupier → const AccountType
- portfolioLead → const AccountType
- supplyPoint → const AccountType
- system → const AccountType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AccountType> - A constant List of the values in this enum, in order of their declaration.