Address class

Constructors

Address({required String addressLine1, String? addressLine2, String? addressLine3, String? county, String? deliveryPointIdentifier, required String postcode, String? town})
Address.fromJson(Map<String, dynamic> json)
factory

Properties

addressLine1 String
getter/setter pair
addressLine2 String?
getter/setter pair
addressLine3 String?
getter/setter pair
county String?
getter/setter pair
deliveryPointIdentifier String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
postcode String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
town String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited