BillingOptions class
Constructors
- BillingOptions({int? periodLength, int? periodStartDay, int? periodStartMonth})
-
BillingOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- periodLength ↔ int?
-
The length of the billing period in months.
getter/setter pair
- periodStartDay ↔ int?
-
The day of the month for the billing period start.
getter/setter pair
- periodStartMonth ↔ int?
-
The month for the billing period start, for quarterly billing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited