Consumption class
Constructors
- Consumption({required double consumption, required DateTime intervalEnd, required DateTime intervalStart})
-
Consumption.fromJson(Map<
String, dynamic> json) -
factory
Properties
- consumption ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intervalEnd ↔ DateTime
-
getter/setter pair
- intervalStart ↔ DateTime
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited