payment property

Payment? payment
getter/setter pair

The payment details are required when using the method 'MONTHLY_DIRECT_DEBIT' but are optional if all the meters are of type PREPAYMENT'. The 'MONTHLY_DIRECT_PAYMENT' method is not available to all users.

Implementation

Payment? payment;