preferredSsd property
A preferred supply start date.
Only include this field if the earliest possible supply startdate is not preferred.
Implementation
DateTime? preferredSsd;
A preferred supply start date.
Only include this field if the earliest possible supply startdate is not preferred.
DateTime? preferredSsd;