quoteRequestCode property
The code of an existing quote created using the 'QuoteNewMeterPoints' mutation as part of the join supplier journey for this new customer. If the quote was generated as part of an affiliate session, the affiliate link and any query parameters belonging to the session will be associated with the created account. Note: only one of 'quote_code' and 'quote_request_code' should be provided in the input.
Implementation
String? quoteRequestCode;