ElectricityMeterPoint class
Constructors
-
ElectricityMeterPoint({Address? address, List<BespokePpsTariffRates>? bespokePpsTariffRates, BespokeTariffRates? bespokeTariffRates, int? consumptionDay, int? consumptionNight, int? consumptionOffPeak, int? consumptionStandard, String? currentSupplierName, String? currentSupplierTariff, ExportDetails? exportDetails, int? fixedTpiFee, String? gsp, bool? hasSmartMeter, bool? isHalfHourly, MeterType? meterType, String? mpan, DateTime? preferredSsd, int? profileClass, Quote? quote, int? quotedProductId, double? standingChargeUplift, String? tariffCode, double? unitRateUplift})
-
-
ElectricityMeterPoint.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
address
↔ Address?
-
getter/setter pairinherited
-
bespokePpsTariffRates
↔ List<BespokePpsTariffRates>?
-
If applicable, must contain two objects: one for direct debit bespoke and
another for non-direct debit bespoke rates. Cannot be used in conjunction
with 'bespoke_tariff_rates'.
getter/setter pairinherited
-
bespokeTariffRates
↔ BespokeTariffRates?
-
A json object containing bespoke tariff rates, if applicable.
getter/setter pairinherited
-
consumptionDay
↔ int?
-
The expected annual consumption for the day/peak register in kWh.
getter/setter pair
-
consumptionNight
↔ int?
-
The expected annual consumption for the night/off-peak register in kWh.
getter/setter pair
-
consumptionOffPeak
↔ int?
-
The expected annual consumption for the additional off-peak register in
kWh.
getter/setter pair
-
consumptionStandard
↔ int?
-
The expected annual consumption for the standard register in kWh.
getter/setter pairinherited
-
currentSupplierName
↔ String?
-
getter/setter pairinherited
-
currentSupplierTariff
↔ String?
-
getter/setter pairinherited
-
exportDetails
↔ ExportDetails?
-
The generation details for the meter-point.
getter/setter pair
-
fixedTpiFee
↔ int?
-
getter/setter pairinherited
-
gsp
↔ String?
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasSmartMeter
↔ bool?
-
Whether a smart meter is installed. The default is 'false'.
getter/setter pairinherited
-
isHalfHourly
↔ bool?
-
Whether the meter point should be enrolled as a half hourly meter point
getter/setter pair
-
meterType
↔ MeterType?
-
The default is 'CREDIT', which represents any kind of traditional credit
meter or smart meter. This field is mandatory for traditional prepay
meters, for which the value 'PREPAYMENT' should be used.
getter/setter pairinherited
-
mpan
↔ String?
-
The meter-point identifier.
getter/setter pair
-
preferredSsd
↔ DateTime?
-
getter/setter pairinherited
-
profileClass
↔ int?
-
getter/setter pair
-
quote
↔ Quote?
-
getter/setter pairinherited
-
quotedProductId
↔ int?
-
The ID of the market supply quoted product returned by the
'QuoteNewMeterPoints' or 'QuoteNewMeterPointsOnBespokeProducts' mutation
which was selected by the customer for this meter point. Required if a
'quote_request_code' is supplied.
getter/setter pairinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
standingChargeUplift
↔ double?
-
The amount to be added to the standing charge as commission (a string,
pence per day).
getter/setter pairinherited
-
tariffCode
↔ String?
-
The tariff code as stored by the supplier.
getter/setter pairinherited
-
unitRateUplift
↔ double?
-
The amount to be added to the unit rate as commission (a string, pence per
kWh).
getter/setter pairinherited