GasMeterPointsService class

Constructors

GasMeterPointsService({required Client client})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listGasMeterConsumption(String mprn, String serialNumber, {String? groupBy, String? orderBy, int? page, int? pageSize, DateTime? periodFrom, DateTime? periodTo}) Future<PaginatedConsumptionList>
Return a list of consumption values (in kWh for SMETS1 and in m^3 for SMETS2) for half-hour periods for a given gas meter-point and meter. WARNING: Half-hourly consumption data is only available for smart meters. Requests for consumption data for non-smart meters will return an empty response payload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited