Installation class

Constructors

Installation({double? capacityInKw, double? estimatedAnnualGenerationInKwh, String? fitId, String? regoId, InstallationTechnologyType? technologyType})
Installation.fromJson(Map<String, dynamic> json)
factory

Properties

capacityInKw double?
The total capacity of the installation in kW.
getter/setter pair
estimatedAnnualGenerationInKwh double?
The estimated annual generation of the installation in kWh.
getter/setter pair
fitId String?
The Feed-in Tariff ID.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
regoId String?
The REGO accreditation number.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
technologyType InstallationTechnologyType?
The technology type for the installation. If there are multiple technologies at one site then provide multiple installations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited