IvrSupportService class

Constructors

IvrSupportService({required Client client})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

minimalTwilioEnqueue() Future<void>
Enqueue a call from Twilio with the fewest steps. Designed to point phone numbers at when Studio is unavailable. May also be useful to mitigate other types of incident. Performs the minimal amount of work to enqueue a call, storing a record of it. As such, non-essential work is omitted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited