MeterPoint class abstract

Implementers

Constructors

MeterPoint({Address? address, List<BespokePpsTariffRates>? bespokePpsTariffRates, BespokeTariffRates? bespokeTariffRates, int? consumptionStandard, String? currentSupplierName, String? currentSupplierTariff, int? fixedTpiFee, bool? hasSmartMeter, MeterType? meterType, DateTime? preferredSsd, Quote? quote, int? quotedProductId, double? standingChargeUplift, String? tariffCode, double? unitRateUplift})

Properties

address Address?
getter/setter pair
bespokePpsTariffRates List<BespokePpsTariffRates>?
If applicable, must contain two objects: one for direct debit bespoke and another for non-direct debit bespoke rates. Cannot be used in conjunction with 'bespoke_tariff_rates'.
getter/setter pair
bespokeTariffRates BespokeTariffRates?
A json object containing bespoke tariff rates, if applicable.
getter/setter pair
consumptionStandard int?
The expected annual consumption for the standard register in kWh.
getter/setter pair
currentSupplierName String?
getter/setter pair
currentSupplierTariff String?
getter/setter pair
fixedTpiFee int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasSmartMeter bool?
Whether a smart meter is installed. The default is 'false'.
getter/setter pair
meterType MeterType?
The default is 'CREDIT', which represents any kind of traditional credit meter or smart meter. This field is mandatory for traditional prepay meters, for which the value 'PREPAYMENT' should be used.
getter/setter pair
preferredSsd DateTime?
getter/setter pair
quote Quote?
getter/setter pair
quotedProductId int?
The ID of the market supply quoted product returned by the 'QuoteNewMeterPoints' or 'QuoteNewMeterPointsOnBespokeProducts' mutation which was selected by the customer for this meter point. Required if a 'quote_request_code' is supplied.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
standingChargeUplift double?
The amount to be added to the standing charge as commission (a string, pence per day).
getter/setter pair
tariffCode String?
The tariff code as stored by the supplier.
getter/setter pair
unitRateUplift double?
The amount to be added to the unit rate as commission (a string, pence per kWh).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited