consumptionStandard property
The expected annual consumption for the standard register in kWh.
Required if standard tariff.
Implementation
int? consumptionStandard;
The expected annual consumption for the standard register in kWh.
Required if standard tariff.
int? consumptionStandard;