unitRateUplift property
The amount to be added to the unit rate as commission (a string, pence per kWh).
Implementation
double? unitRateUplift;
The amount to be added to the unit rate as commission (a string, pence per kWh).
double? unitRateUplift;