OctopusEnergyApiClient class

Constructors

OctopusEnergyApiClient({Client? client})

Properties

accounts AccountsService
no setter
electricityMeterPoints ElectricityMeterPointsService
no setter
gasMeterPoints GasMeterPointsService
no setter
hashCode int
The hash code for this object.
no setterinherited
industry IndustryService
no setter
ivrSupport IvrSupportService
no setter
products ProductsService
no setter
quotes QuotesService
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voice VoiceService
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited