Payment class

Constructors

Payment({String? accountName, String? accountNumber, String? accountSortCode, int? delayDays, required PaymentMethod method, int? paymentDay})
Payment.fromJson(Map<String, dynamic> json)
factory

Properties

accountName String?
The name associated with the bank account.
getter/setter pair
accountNumber String?
The bank account number.
getter/setter pair
accountSortCode String?
The bank account sort code.
getter/setter pair
delayDays int?
The number of days to delay the payment for a bill triggered schedule.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
method PaymentMethod
getter/setter pair
paymentDay int?
The preferred day of the month for the payment request.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited