Proprietor class

Constructors

Proprietor({ProprietorAddress? address, DateTime? dateOfBirth, required String emailAddress, required String firstName, required String lastName, String? phoneNumber})
Proprietor.fromJson(Map<String, dynamic> json)
factory

Properties

address ProprietorAddress?
Main address of a business owner (only required for non limited companies).
getter/setter pair
dateOfBirth DateTime?
Date of birth of the business owner (only required for non limited companies).
getter/setter pair
emailAddress String
Email address from a business owner.
getter/setter pair
firstName String
First name of the business owner.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastName String
Last name of the business owner.
getter/setter pair
phoneNumber String?
Phone number of a business owner.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited