ProprietorAddress class

Constructors

ProprietorAddress({required String line1, String? line2, String? line3, String? line4, String? line5, required String postcode})
ProprietorAddress.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
line1 String
First line of address.
getter/setter pair
line2 String?
Second line of address.
getter/setter pair
line3 String?
Third line of address.
getter/setter pair
line4 String?
Fourth line of address.
getter/setter pair
line5 String?
Fifth line of address.
getter/setter pair
postcode String
Postcode of the address.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited