Quote class

Constructors

Quote({int? annualPayment})
Quote.fromJson(Map<String, dynamic> json)
factory

Properties

annualPayment int?
The estimated annual payment for this meter-point based on consumption.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited