SalesChannel enum

Inheritance
Available extensions

Values

acquisition → const SalesChannel

Acquisition.

aggregator → const SalesChannel

Aggregator.

broker → const SalesChannel

Broker.

currentAccount → const SalesChannel

Current Account.

debtCollectionAgency → const SalesChannel

Debt collection agency.

digiTelesales → const SalesChannel

Digital telesales.

direct → const SalesChannel

Direct.

events → const SalesChannel

Events.

fieldSales → const SalesChannel

Field sales.

giftOfKit → const SalesChannel

Gift of kit.

highReferrer → const SalesChannel

High referrer.

landlord → const SalesChannel

Landlord.

moveIn → const SalesChannel

Move in.

newTenant → const SalesChannel

New tenant.

octopusTrustedPartners → const SalesChannel

Octopus Trusted Partners.

parentPower → const SalesChannel

Parent power.

partnerships → const SalesChannel

Partnerships.

peoplePower → const SalesChannel

People power.

priceComparison → const SalesChannel

Price comparison.

supplierOfLastResort → const SalesChannel

Supplier of last resort.

telesales → const SalesChannel

Telesales.

workplacePopUp → const SalesChannel

Workplace pop-up.

worksWithOctopus → const SalesChannel

Works with octopus.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SalesChannel>
A constant List of the values in this enum, in order of their declaration.