SampleQuotes class

Constructors

SampleQuotes({Map<String, double>? dualFuelDualRate, Map<String, double>? dualFuelSingleRate, Map<String, double>? electricityDualRate, Map<String, double>? electricitySingleRate})
SampleQuotes.fromJson(Map<String, dynamic> json)
factory

Properties

dualFuelDualRate Map<String, double>?
Annual cost (inc or exc)
getter/setter pair
dualFuelSingleRate Map<String, double>?
Annual cost (inc or exc)
getter/setter pair
electricityDualRate Map<String, double>?
Annual cost (inc or exc)
getter/setter pair
electricitySingleRate Map<String, double>?
Annual cost (inc or exc)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited