SmartMeterInterest enum

The occupier’s interest in installing a smart meter.

Inheritance
Available extensions

Values

smets2InterestInterested → const SmartMeterInterest

Interested.

smets2InterestNotAtTheMoment → const SmartMeterInterest

No interest at the moment, ask again later.

smets2InterestNotInterested → const SmartMeterInterest

Not Interested.

smets2InterestPriority → const SmartMeterInterest

Priority.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SmartMeterInterest>
A constant List of the values in this enum, in order of their declaration.