User class
Constructors
- User({CreditScoreData? creditScoreData, DateTime? dateOfBirth, required String email, required String familyName, required String givenName, String? label, String? landline, String? mobile, required bool optedInForMarketing, bool? optedInToThirdParties, Psr? psr, String? title})
-
User.fromJson(Map<
String, dynamic> json) -
factory
Properties
- creditScoreData ↔ CreditScoreData?
-
getter/setter pair
- dateOfBirth ↔ DateTime?
-
getter/setter pair
- email ↔ String
-
Cannot already be in use for an existing account.
getter/setter pair
- familyName ↔ String
-
getter/setter pair
- givenName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- label ↔ String?
-
getter/setter pair
- landline ↔ String?
-
getter/setter pair
- mobile ↔ String?
-
getter/setter pair
- optedInForMarketing ↔ bool
-
getter/setter pair
- optedInToThirdParties ↔ bool?
-
getter/setter pair
- psr ↔ Psr?
-
Priority Services Register details for the user
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited