v1 library
Classes
- Account
- AccountAgreement
- AccountElectricityMeterPoint
- AccountElectricityMeterPointMeter
- AccountGasMeterPoint
- AccountGasMeterPointMeter
-
AccountMeterPoint<
T extends AccountMeterPointMeter> - AccountMeterPointMeter
- AccountProperty
- AccountRegister
- AccountsService
- Address
- Affiliate
- This serializer is used to allow affiliates to pass a signup reward code when creating accounts which later will then give credit to the accounts once their payments start.
- Agreement
- AgreementsCreated
- ApiKeyClient
- Adds 'authorization' header with an API key when making HTTP requests.
- BespokeElectricityUnitRate
- BespokePpsTariffRates
- BespokeTariffRates
- BillingOptions
- Business
- BusinessTariffRenewal
- BusinessTariffRenewalAgreement
- BusinessTariffRenewalBespokeRegisterRate
- BusinessTariffRenewalBespokeTariffRate
- BusinessTariffRenewalCommission
- Consumption
- Create
- Serializer to create an account via a REST API.
- CreditScoreData
- Deposit
- Eco7ElectricityTariff
- ElectricityMeterPoint
- ElectricityMeterPointsService
- Emails
- ExportDetails
- FourRateEvElectricityTariff
- GasMeterPoint
- GasMeterPointsService
- GasTariff
- GridSupplyPoint
- HistoricalCharge
- IndustryService
- Installation
- IvrSupportService
- Link
- Metadata
- MeterPoint
- OctopusEnergyApiClient
- PaginatedConsumptionList
- PaginatedGridSupplyPointList
- PaginatedHistoricalChargeList
- PaginatedProductsList
- PasswordReset
- Payment
- Product
- Products
- ProductsService
- Proprietor
- ProprietorAddress
- Psr
- Quote
- QuoteCreated
- QuoteProduct
- QuotesService
- QuoteTil
- SampleConsumption
- SampleQuotes
- StandardElectricityTariff
- SuccessResponse
- User
- VoiceService
Enums
- AccountSource
- AccountType
- BespokePaymentMethod
- The payment method for the rate.
- BespokeRateType
- The rate type of the unit rate.
- BrandCode
- A code to specify the account should be for a particular brand.
- BusinessType
- CreditRiskBracket
- Direction
- InstallationTechnologyType
- The technology type for the installation.
- MeterType
- The default is 'CREDIT', which represents any kind of traditional credit meter or smart meter. This field is mandatory for traditional prepay meters, for which the value 'PREPAYMENT' should be used.
- PaymentMethod
- SalesChannel
- SmartMeterInterest
- The occupier’s interest in installing a smart meter.
- SmartMeterReadPermission
- The read permission frequency the occupier grants to meter readings from smart meters.
- SmartOnboardingProductType
- A code to indicate which type of smart tariff the customer is meant to onboard onto.
Constants
- The authority of the Octopus Energy API.
Functions
-
clientViaApiKey(
String apiKey, {Client? inner}) → Client -
Obtains a Client that uses the given
apiKeyfor making HTTP requests.