AccountElectricityMeterPoint class
- Inheritance
-
- Object
- AccountMeterPoint<
AccountElectricityMeterPointMeter> - AccountElectricityMeterPoint
Constructors
-
AccountElectricityMeterPoint({List<
AccountAgreement> ? agreements, int? consumptionStandard, bool? isExport, List<AccountElectricityMeterPointMeter> ? meters, required String mpan, int? profileClass}) -
AccountElectricityMeterPoint.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
agreements
↔ List<
AccountAgreement> ? -
getter/setter pairinherited
- consumptionStandard ↔ int?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExport ↔ bool?
-
getter/setter pair
-
meters
↔ List<
AccountElectricityMeterPointMeter> ? -
getter/setter pairinherited
- mpan ↔ String
-
getter/setter pair
- profileClass ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited