AccountsService class
Constructors
- AccountsService({required Client client})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAccount(
Create create) → Future< SuccessResponse> - WARNING: This endpoint is only available to partner organisations.
-
getAccount(
String accountNumber) → Future< Account> - Retrieve the details of an account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renewBusinessTariff(
String accountNumber, BusinessTariffRenewal renewal) → Future< AgreementsCreated> - This end-point allows a new agreement to be created for an existing account. It is restricted to business accounts. WARNING: This endpoint is only available to partner organisations.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited