BespokeElectricityUnitRate class
Constructors
- BespokeElectricityUnitRate({BespokePaymentMethod? paymentMethod, BespokeRateType? rateType, double? unitRate})
-
BespokeElectricityUnitRate.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentMethod ↔ BespokePaymentMethod?
-
The payment method for the rate.
getter/setter pair
- rateType ↔ BespokeRateType?
-
The rate type of the unit rate.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unitRate ↔ double?
-
The value in pence per kWh of the charge (excluding VAT).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited