BespokeRateType enum
The rate type of the unit rate.
If the register_identifier is not provided, the rate type must be provided instead.
Values
- capacityMarket → const BespokeRateType
-
Capacity Market rate (pence per day) for business tariffs.
- eco7Day → const BespokeRateType
-
Day (or peak) rate (pence per kWh).
- eco7Night → const BespokeRateType
-
Night (or off-peak) rate (pence per kWh).
- evDevice → const BespokeRateType
-
Electric vehicle device rate (pence per kWh) for sub-meter billing.
- evDeviceOffPeak → const BespokeRateType
-
Electric vehicle device off-peak rate (pence per kWh) for sub-meter billing.
- evDevicePeak → const BespokeRateType
-
Electric vehicle device peak rate (pence per kWh) for sub-meter billing.
- hmcGuaranteeAdvance → const BespokeRateType
-
Hourly Matching Credit Guarantee Advance rate (pence per kWh) for business tariffs.
- hmcGuaranteeFull → const BespokeRateType
-
Hourly Matching Credit Guarantee Full rate (pence per kWh) for business tariffs.
- nuclearRab → const BespokeRateType
-
Nuclear RAB rate (pence per day) for business tariffs.
- offPeak → const BespokeRateType
-
Additional off-peak rate for three-rate tariffs (pence per kWh).
- offPeakWeekends → const BespokeRateType
-
Off peak weekend rate (pence per kWh) for business tariffs.
- peak → const BespokeRateType
-
Peak rate (pence per kWh) for business tariffs.
- standard → const BespokeRateType
-
Standard rate (pence per kWh).
- summer → const BespokeRateType
-
Summer rate (pence per kWh) for business tariffs.
- summerOffPeak → const BespokeRateType
-
Summer off-peak rate (pence per kWh) for two-rate tariffs.
- summerPeak → const BespokeRateType
-
Summer peak rate (pence per kWh) for two-rate tariffs.
- summerWeekendsOffPeakWinter → const BespokeRateType
-
A rate that applies during summer, weekends and off-peak in winter periods (pence per kWh) for business tariffs.
- tnuos → const BespokeRateType
-
TNUoS rate (pence per day) for business tariffs.
- weekday → const BespokeRateType
-
Weekday rate (pence per kWh) for business tariffs.
- weekendsOther → const BespokeRateType
-
Weekend rate (pence per kWh) for business tariffs.
- winter → const BespokeRateType
-
Winter rate (pence per kWh) for business tariffs.
- winterOffPeak → const BespokeRateType
-
Winter off-peak rate (pence per kWh) for two-rate tariffs.
- winterPeak → const BespokeRateType
-
Winter peak rate (pence per kWh) for two-rate tariffs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BespokeRateType> - A constant List of the values in this enum, in order of their declaration.