ExportDetails class
Constructors
-
ExportDetails({String? importMpan, List<
Installation> ? installations, String? siteContactEmail, String? siteContactName, String? siteContactPhone}) -
ExportDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- importMpan ↔ String?
-
The import MPAN.
getter/setter pair
-
installations
↔ List<
Installation> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- siteContactEmail ↔ String?
-
The email address of the site contact.
getter/setter pair
- siteContactName ↔ String?
-
The name of the site contact.
getter/setter pair
- siteContactPhone ↔ String?
-
The phone number of the site contact.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited