-
address
↔ Address?
-
getter/setter pairinherited
-
bespokePpsTariffRates
↔ List<BespokePpsTariffRates>?
-
If applicable, must contain two objects: one for direct debit bespoke and
another for non-direct debit bespoke rates. Cannot be used in conjunction
with 'bespoke_tariff_rates'.
getter/setter pairinherited
-
bespokeTariffRates
↔ BespokeTariffRates?
-
A json object containing bespoke tariff rates, if applicable.
getter/setter pairinherited
-
consumptionStandard
↔ int?
-
The expected annual consumption for the standard register in kWh.
getter/setter pairinherited
-
currentSupplierName
↔ String?
-
getter/setter pairinherited
-
currentSupplierTariff
↔ String?
-
getter/setter pairinherited
-
fixedTpiFee
↔ int?
-
getter/setter pairinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasSmartMeter
↔ bool?
-
Whether a smart meter is installed. The default is 'false'.
getter/setter pairinherited
-
meterType
↔ MeterType?
-
The default is 'CREDIT', which represents any kind of traditional credit
meter or smart meter. This field is mandatory for traditional prepay
meters, for which the value 'PREPAYMENT' should be used.
getter/setter pairinherited
-
mprn
↔ String?
-
The meter-point identifier.
getter/setter pair
-
preferredSsd
↔ DateTime?
-
getter/setter pairinherited
-
quote
↔ Quote?
-
getter/setter pairinherited
-
quotedProductId
↔ int?
-
The ID of the market supply quoted product returned by the
'QuoteNewMeterPoints' or 'QuoteNewMeterPointsOnBespokeProducts' mutation
which was selected by the customer for this meter point. Required if a
'quote_request_code' is supplied.
getter/setter pairinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
standingChargeUplift
↔ double?
-
The amount to be added to the standing charge as commission (a string,
pence per day).
getter/setter pairinherited
-
tariffCode
↔ String?
-
The tariff code as stored by the supplier.
getter/setter pairinherited
-
unitRateUplift
↔ double?
-
The amount to be added to the unit rate as commission (a string, pence per
kWh).
getter/setter pairinherited