If applicable, must contain two objects: one for direct debit bespoke and
another for non-direct debit bespoke rates. Cannot be used in conjunction
with 'bespoke_tariff_rates'.
The default is 'CREDIT', which represents any kind of traditional credit
meter or smart meter. This field is mandatory for traditional prepay
meters, for which the value 'PREPAYMENT' should be used.
The ID of the market supply quoted product returned by the
'QuoteNewMeterPoints' or 'QuoteNewMeterPointsOnBespokeProducts' mutation
which was selected by the customer for this meter point. Required if a
'quote_request_code' is supplied.