Product class
Constructors
-
Product({required DateTime availableFrom, DateTime? availableTo, required String brand, required String code, required String description, required String displayName, Map<
String, Map< ? dualRegisterElectricityTariffs, Map<String, Eco7ElectricityTariff> >String, Map< ? fourRateEvElectricityTariffs, required String fullName, bool? isBusiness, bool? isGreen, bool? isPrepay, required bool isRestricted, bool? isTracker, bool? isVariable, required List<String, FourRateEvElectricityTariff> >Link> links, SampleConsumption? sampleConsumption, SampleQuotes? sampleQuotes, Map<String, Map< ? singleRegisterElectricityTariffs, Map<String, StandardElectricityTariff> >String, Map< ? singleRegisterGasTariffs, required DateTime tariffsActiveAt, int? term})String, GasTariff> > -
Product.fromJson(Map<
String, dynamic> json) -
factory
Properties
- availableFrom ↔ DateTime
-
getter/setter pair
- availableTo ↔ DateTime?
-
getter/setter pair
- brand ↔ String
-
getter/setter pair
- code ↔ String
-
getter/setter pair
- description ↔ String
-
This will be shown to customers during sign-up
getter/setter pair
- displayName ↔ String
-
This name will be shown to customers during sign-up
getter/setter pair
-
dualRegisterElectricityTariffs
↔ Map<
String, Map< ?String, Eco7ElectricityTariff> > -
getter/setter pair
-
fourRateEvElectricityTariffs
↔ Map<
String, Map< ?String, FourRateEvElectricityTariff> > -
getter/setter pair
- fullName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBusiness ↔ bool?
-
Is a business product?
getter/setter pair
- isGreen ↔ bool?
-
Is a green product?
getter/setter pair
- isPrepay ↔ bool?
-
getter/setter pair
- isRestricted ↔ bool
-
getter/setter pair
- isTracker ↔ bool?
-
Is a tracker product?
getter/setter pair
- isVariable ↔ bool?
-
Is variable?
getter/setter pair
-
links
↔ List<
Link> -
Historical charges can be browsed using the provided URLs.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleConsumption ↔ SampleConsumption?
-
getter/setter pair
- sampleQuotes ↔ SampleQuotes?
-
getter/setter pair
-
singleRegisterElectricityTariffs
↔ Map<
String, Map< ?String, StandardElectricityTariff> > -
getter/setter pair
-
singleRegisterGasTariffs
↔ Map<
String, Map< ?String, GasTariff> > -
getter/setter pair
- tariffsActiveAt ↔ DateTime
-
getter/setter pair
- term ↔ int?
-
Duration of agreements using this product in months
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited